@@ -31,12 +31,11 @@ void test01()
   bool test __attribute__((unused)) = true;
 
   wostringstream oss_01;
-  const wstring str_01(50, L'a');
 
   oss_01.width(5000000);
   const streamsize width = oss_01.width();
 
-  oss_01 << str_01.c_str();
+  oss_01 << L'a';
 
   VERIFY( oss_01.good() );
   VERIFY( oss_01.str().size() == wstring::size_type(width) );
